pub fn cuboid_triangle_find_local_separating_edge_twoway(
cube1: &Cuboid,
triangle2: &Triangle,
pos12: &Isometry<f64>,
) -> (f64, Vector<f64>)Expand description
Finds the best separating edge between a cuboid and a triangle.
All combinations of edges from the cuboid and the triangle are taken into account.