pub fn segment_triangle_find_local_separating_edge_twoway(
segment1: &Segment,
triangle2: &Triangle,
pos12: &Isometry<f64>,
) -> (f64, Vector<f64>)Expand description
Finds the best separating edge between a segment and a triangle.
All combinations of edges from the segment and the triangle are taken into account.